# json-work-manager

https://pypi.org/project/json-work-manager
<pre>
pip install json-work-manager
</pre>

Examples  

Basic  
https://github.com/automatethem/json-work-manager/blob/main/examples/basic/json_work.py   
https://github.com/automatethem/json-work-managerr/blob/main/examples/basic/inputs/config.json

Chrome  
https://github.com/automatethem/json-work-manager/blob/main/examples/chrome/inputs/config.json
